=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2006-02-21 07:03:59 +0000
+++ bzrlib/lockdir.py	2006-02-21 07:48:58 +0000
@@ -201,6 +201,22 @@
         self.transport.delete(tmpname + self.INFO_NAME)
         self.transport.rmdir(tmpname)
 
+    def confirm(self):
+        """Make sure that the lock is still held by this locker.
+
+        This should only fail if the lock was broken by user intervention,
+        or if the lock has been affected by a bug.
+
+        If the lock is not thought to be held, raises LockNotHeld.  If
+        the lock is thought to be held but has been broken, raises 
+        LockBroken.
+        """
+        if not self._lock_held:
+            raise LockNotHeld(self)
+        # info = self.peek()
+        # if info['nonce'] != self._nonce:
+        #     raise LockBroken(self)
+
     def peek(self):
         """Check if the lock is held by anyone.
         

=== modified file 'bzrlib/tests/test_lockdir.py'
--- bzrlib/tests/test_lockdir.py	2006-02-21 06:02:01 +0000
+++ bzrlib/tests/test_lockdir.py	2006-02-21 07:48:58 +0000
@@ -19,7 +19,8 @@
 from threading import Thread
 import time
 
-from bzrlib.errors import LockContention, LockError, UnlockableTransport
+from bzrlib.errors import LockContention, LockError, UnlockableTransport, \
+        LockNotHeld
 from bzrlib.lockdir import LockDir
 from bzrlib.tests import TestCaseInTempDir, TestCaseWithTransport
 
@@ -193,3 +194,16 @@
             self.assertTrue(after - before <= 1.0)
         finally:
             unlocker.join()
+
+    def test_40_confirm_easy(self):
+        """Confirm a lock that's already held"""
+        t = self.get_transport()
+        lf1 = LockDir(t, 'test_lock')
+        lf1.attempt_lock()
+        lf1.confirm()
+
+    def test_41_confirm_not_held(self):
+        """Confirm a lock that's already held"""
+        t = self.get_transport()
+        lf1 = LockDir(t, 'test_lock')
+        self.assertRaises(LockNotHeld, lf1.confirm)

